# smpl_doc
Simplified plotting and fitting in python.

[![PyPI version][pypi image]][pypi link] [![PyPI version][pypi versions]][pypi link]  ![downloads](https://img.shields.io/pypi/dm/smpl_doc.svg)

 [![test][a t image]][a t link]    [![Coverage Status][c t i]][c t l]  [![Documentation][rtd t i]][rtd t l]

## Documentation

-   <https://apn-pucky.github.io/smpl_doc/index.html>

## Versions

### Stable

```sh
pip install smpl_doc
```

Optional: --user or --upgrade

### Dev

```sh
pip install --index-url https://test.pypi.org/simple/ smpl_doc
```

[doc stable]: https://apn-pucky.github.io/smpl_doc/index.html
[doc test]: https://apn-pucky.github.io/smpl_doc/test/index.html

[pypi image]: https://badge.fury.io/py/smpl_doc.svg
[pypi link]: https://pypi.org/project/smpl_doc/
[pypi versions]: https://img.shields.io/pypi/pyversions/smpl_doc.svg

[a s image]: https://github.com/APN-Pucky/smpl_doc/actions/workflows/stable.yml/badge.svg
[a s link]: https://github.com/APN-Pucky/smpl_doc/actions/workflows/stable.yml
[a t link]: https://github.com/APN-Pucky/smpl_doc/actions/workflows/test.yml
[a t image]: https://github.com/APN-Pucky/smpl_doc/actions/workflows/test.yml/badge.svg

[cc s q i]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2?branch=stable
[cc s q l]: https://www.codacy.com/gh/APN-Pucky/smpl_doc/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl&amp;utm_campaign=Badge_Grade?branch=stable
[cc s c i]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2?branch=stable
[cc s c l]: https://www.codacy.com/gh/APN-Pucky/smpl_doc/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl&utm_campaign=Badge_Coverage?branch=stable

[cc q i]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2
[cc q l]: https://www.codacy.com/gh/APN-Pucky/smpl_doc/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl&amp;utm_campaign=Badge_Grade
[cc c i]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2
[cc c l]: https://www.codacy.com/gh/APN-Pucky/smpl_doc/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl&utm_campaign=Badge_Coverage

[c s i]: https://coveralls.io/repos/github/APN-Pucky/smpl_doc/badge.svg?branch=stable
[c s l]: https://coveralls.io/github/APN-Pucky/smpl_doc?branch=stable
[c t l]: https://coveralls.io/github/APN-Pucky/smpl_doc?branch=master
[c t i]: https://coveralls.io/repos/github/APN-Pucky/smpl_doc/badge.svg?branch=master

[rtd s i]: https://readthedocs.org/projects/smpl_doc/badge/?version=stable
[rtd s l]: https://smpl_doc.readthedocs.io/en/stable/?badge=stable
[rtd t i]: https://readthedocs.org/projects/smpl_doc/badge/?version=latest
[rtd t l]: https://smpl_doc.readthedocs.io/en/latest/?badge=latest
